@@ -1,18 +1,20 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2016 Alexander Todorov <atodorov@otb.bg>
-# Copyright (c) 2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2017-2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2019, 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2021 bernie gray <bfgray3@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
-"""Looks for  comparisons to empty string."""
+"""Looks for comparisons to zero."""
 
 import itertools
 
 import astroid
 
-from pylint import interfaces
-from pylint import checkers
+from pylint import checkers, interfaces
 from pylint.checkers import utils
 
 
@@ -60,10 +62,10 @@ class CompareToZeroChecker(checkers.BaseChecker):
             error_detected = False
 
             # 0 ?? X
-            if _is_constant_zero(op_1) and op_2 in _operators + ["<"]:
+            if _is_constant_zero(op_1) and op_2 in _operators:
                 error_detected = True
             # X ?? 0
-            elif op_2 in _operators + [">"] and _is_constant_zero(op_3):
+            elif op_2 in _operators and _is_constant_zero(op_3):
                 error_detected = True
 
             if error_detected:
