@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2013-2014 Google, Inc.
 # Copyright (c) 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2014 Arun Persaud <arun@nubati.net>
@@ -7,35 +6,22 @@
 # Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
 # Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2016 Glenn Matthews <glenn@e-dad.net>
+# Copyright (c) 2017-2019, 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2017-2018, 2020 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2017 Pierre Sassoulas <pierre.sassoulas@cea.fr>
 # Copyright (c) 2017 ttenhoeve-aa <ttenhoeve@appannie.com>
 # Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
-# Copyright (c) 2018-2019 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2018 Pierre Sassoulas <pierre.sassoulas@wisebim.fr>
 # Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2020 Peter Kolbus <peter.kolbus@gmail.com>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 import io
-import re
 
 from pylint.utils import utils
 
 
-def test__basename_in_blacklist_re_match():
-    patterns = [re.compile(".*enchilada.*"), re.compile("unittest_.*")]
-    assert utils._basename_in_blacklist_re("unittest_utils.py", patterns)
-    assert utils._basename_in_blacklist_re("cheese_enchiladas.xml", patterns)
-
-
-def test__basename_in_blacklist_re_nomatch():
-    patterns = [re.compile(".*enchilada.*"), re.compile("unittest_.*")]
-    assert not utils._basename_in_blacklist_re("test_utils.py", patterns)
-    assert not utils._basename_in_blacklist_re("enchilad.py", patterns)
-
-
 def test_decoding_stream_unknown_encoding():
     """decoding_stream should fall back to *some* decoding when given an
     unknown encoding.
